@@ -3,25 +3,25 @@
 # changes made to this file will be lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION == "2.0.0" or
-    raise "ruby lib version (2.0.0) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION == "2.1.9" or
+    raise "ruby lib version (2.1.9) doesn't match executable version (#{RUBY_VERSION})"
 
-  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby2.0/2.0.0/x86_64-darwin15")
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby2.1/2.1.0/x86_64-darwin15")
   DESTDIR = '' unless defined? DESTDIR
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "2"
-  CONFIG["MINOR"] = "0"
+  CONFIG["MINOR"] = "1"
   CONFIG["TEENY"] = "0"
-  CONFIG["PATCHLEVEL"] = "648"
+  CONFIG["PATCHLEVEL"] = "490"
   CONFIG["INSTALL"] = '/usr/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/opt/local")
-  CONFIG["ruby_install_name"] = "ruby2.0"
-  CONFIG["RUBY_INSTALL_NAME"] = "ruby2.0"
-  CONFIG["RUBY_SO_NAME"] = "ruby.2.0.0"
+  CONFIG["ruby_install_name"] = "ruby2.1"
+  CONFIG["RUBY_INSTALL_NAME"] = "ruby2.1"
+  CONFIG["RUBY_SO_NAME"] = "ruby.2.1.0"
   CONFIG["exec"] = "exec"
-  CONFIG["ruby_pc"] = "ruby-2.0.pc"
+  CONFIG["ruby_pc"] = "ruby-2.1.pc"
   CONFIG["PACKAGE"] = "ruby"
   CONFIG["BUILTIN_TRANSSRCS"] = " newline.c"
   CONFIG["USE_RUBYGEMS"] = "YES"
@@ -33,9 +33,10 @@ module RbConfig
   CONFIG["vendorhdrdir"] = "$(rubyhdrdir)/vendor_ruby"
   CONFIG["sitehdrdir"] = "$(rubyhdrdir)/site_ruby"
   CONFIG["rubyhdrdir"] = "$(includedir)/$(RUBY_VERSION_NAME)"
+  CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--prefix=/opt/local' '--enable-shared' '--disable-install-doc' '--mandir=/opt/local/share/man' '--enable-pthread' '--without-tk' '--with-opt-dir=/opt/local' '--with-openssl-include=/opt/local/libexec/openssl10/include' '--with-openssl-lib=/opt/local/libexec/openssl10/lib' '--program-suffix=2.0' '--with-rubylibprefix=/opt/local/lib/ruby2.0' '--with-arch=x86_64' 'CC=/usr/bin/clang' 'CFLAGS=-pipe -I/opt/local/libexec/openssl10/include -Os -Wno-error=implicit-function-declaration -arch x86_64' 'LDFLAGS=-L/opt/local/libexec/openssl10/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -arch x86_64' 'CPPFLAGS=-I/opt/local/libexec/openssl10/include -isystem/opt/local/include' 'CXX=/usr/bin/clang++' 'CXXFLAGS=-pipe -I/opt/local/libexec/openssl10/include -Os -stdlib=libc++ -arch x86_64' 'PKG_CONFIG_PATH=/opt/local/lib/openssl-1.0/pkgconfig:/opt/local/libexec/openssl10/lib/pkgconfig'"
+  CONFIG["configure_args"] = " '--prefix=/opt/local' '--enable-shared' '--disable-install-doc' '--mandir=/opt/local/share/man' '--enable-pthread' '--without-tk' '--without-gmp' '--with-opt-dir=/opt/local' '--with-openssl-include=/opt/local/libexec/openssl10/include' '--with-openssl-lib=/opt/local/libexec/openssl10/lib' '--program-suffix=2.1' '--with-rubylibprefix=/opt/local/lib/ruby2.1' '--with-arch=x86_64' 'CC=/usr/bin/clang' 'CFLAGS=-pipe -I/opt/local/libexec/openssl10/include -Os -Wno-error=implicit-function-declaration -arch x86_64' 'LDFLAGS=-L/opt/local/libexec/openssl10/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -arch x86_64' 'CPPFLAGS=-I/opt/local/libexec/openssl10/include -isystem/opt/local/include' 'CXX=/usr/bin/clang++' 'CXXFLAGS=-pipe -I/opt/local/libexec/openssl10/include -Os -stdlib=libc++ -arch x86_64' 'PKG_CONFIG_PATH=/opt/local/libexec/openssl10/lib/pkgconfig'"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
   CONFIG["vendordir"] = "$(rubylibprefix)/vendor_ruby"
@@ -44,19 +45,22 @@ module RbConfig
   CONFIG["sitedir"] = "$(rubylibprefix)/site_ruby"
   CONFIG["rubyarchdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["rubylibdir"] = "$(rubylibprefix)/$(ruby_version)"
-  CONFIG["ruby_version"] = "2.0.0"
+  CONFIG["ruby_version"] = "2.1.0"
   CONFIG["sitearch"] = "$(arch)"
   CONFIG["arch"] = "x86_64-darwin15"
   CONFIG["sitearchincludedir"] = "$(includedir)/$(sitearch)"
   CONFIG["archincludedir"] = "$(includedir)/$(arch)"
   CONFIG["sitearchlibdir"] = "$(libdir)/$(sitearch)"
   CONFIG["archlibdir"] = "$(libdir)/$(arch)"
+  CONFIG["libdirname"] = "libdir"
+  CONFIG["RUBY_EXEC_PREFIX"] = "/opt/local"
+  CONFIG["RUBY_LIB_VERSION"] = ""
+  CONFIG["RUBY_LIB_VERSION_STYLE"] = "3\t/* full */"
   CONFIG["RI_BASE_NAME"] = "ri"
   CONFIG["ridir"] = "$(datarootdir)/$(RI_BASE_NAME)"
   CONFIG["rubysitearchprefix"] = "$(rubylibprefix)/$(sitearch)"
   CONFIG["rubyarchprefix"] = "$(rubylibprefix)/$(arch)"
-  CONFIG["rubylibprefix"] = "$(libdir)/$(RUBY_BASE_NAME)2.0"
-  CONFIG["MAKEFILES"] = "Makefile"
+  CONFIG["MAKEFILES"] = "Makefile GNUmakefile"
   CONFIG["PLATFORM_DIR"] = ""
   CONFIG["THREAD_MODEL"] = "pthread"
   CONFIG["SYMBOL_PREFIX"] = "_"
@@ -67,9 +71,9 @@ module RbConfig
   CONFIG["MAINLIBS"] = ""
   CONFIG["ENABLE_SHARED"] = "yes"
   CONFIG["DLDLIBS"] = ""
-  CONFIG["SOLIBS"] = ""
+  CONFIG["SOLIBS"] = "$(LIBS)"
   CONFIG["LIBRUBYARG_SHARED"] = "-l$(RUBY_SO_NAME)"
-  CONFIG["LIBRUBYARG_STATIC"] = "-l$(RUBY_SO_NAME)-static"
+  CONFIG["LIBRUBYARG_STATIC"] = "-l$(RUBY_SO_NAME)-static -framework CoreFoundation"
   CONFIG["LIBRUBYARG"] = "$(LIBRUBYARG_SHARED)"
   CONFIG["LIBRUBY"] = "$(LIBRUBY_SO)"
   CONFIG["LIBRUBY_ALIASES"] = "lib$(RUBY_BASE_NAME).$(MAJOR).$(MINOR).dylib lib$(RUBY_INSTALL_NAME).dylib"
@@ -77,12 +81,10 @@ module RbConfig
   CONFIG["LIBRUBY_A"] = "lib$(RUBY_SO_NAME)-static.a"
   CONFIG["RUBYW_INSTALL_NAME"] = ""
   CONFIG["rubyw_install_name"] = ""
-  CONFIG["LIBRUBY_DLDFLAGS"] = "-Wl,-undefined,dynamic_lookup -Wl,-multiply_defined,suppress -L/opt/local/lib  -install_name $(libdir)/$(LIBRUBY_SO) -current_version $(MAJOR).$(MINOR).$(TEENY) -compatibility_version $(ruby_version)  $(XLDFLAGS)"
-  CONFIG["LIBRUBY_LDSHARED"] = "$(CC) -dynamiclib"
   CONFIG["EXTDLDFLAGS"] = ""
   CONFIG["EXTLDFLAGS"] = ""
   CONFIG["strict_warnflags"] = ""
-  CONFIG["warnflags"] = "-Wall -Wextra -Wno-unused-parameter -Wno-parentheses -Wno-long-long -Wno-missing-field-initializers -Wunused-variable -Wpointer-arith -Wwrite-strings -Wdeclaration-after-statement -Wshorten-64-to-32 -Wimplicit-function-declaration"
+  CONFIG["warnflags"] = "-Wall -Wextra -Wno-unused-parameter -Wno-parentheses -Wno-long-long -Wno-missing-field-initializers -Wunused-variable -Wpointer-arith -Wwrite-strings -Wdeclaration-after-statement -Wshorten-64-to-32 -Wimplicit-function-declaration -Wdivision-by-zero -Wextra-tokens"
   CONFIG["debugflags"] = "-ggdb3"
   CONFIG["optflags"] = "-O3 -fno-fast-math"
   CONFIG["cxxflags"] = " $(optflags) $(debugflags) $(warnflags)"
@@ -105,6 +107,7 @@ module RbConfig
   CONFIG["BTESTRUBY"] = "$(MINIRUBY)"
   CONFIG["CROSS_COMPILING"] = "no"
   CONFIG["TEST_RUNNABLE"] = "yes"
+  CONFIG["rubylibprefix"] = "$(exec_prefix)/lib/ruby2.1"
   CONFIG["setup"] = "Setup"
   CONFIG["EXTSTATIC"] = ""
   CONFIG["STRIP"] = "strip -A -n"
@@ -112,7 +115,7 @@ module RbConfig
   CONFIG["LIBPATHENV"] = "DYLD_LIBRARY_PATH"
   CONFIG["RPATHFLAG"] = ""
   CONFIG["LIBPATHFLAG"] = " -L%s"
-  CONFIG["LINK_SO"] = "\ntest -z '$(RUBY_CODESIGN)' || codesign -s '$(RUBY_CODESIGN)' -f $@"
+  CONFIG["LINK_SO"] = "\n$(POSTLINK)"
   CONFIG["LIBEXT"] = "a"
   CONFIG["DLEXT2"] = ""
   CONFIG["DLEXT"] = "bundle"
@@ -133,7 +136,7 @@ module RbConfig
   CONFIG["CP"] = "cp"
   CONFIG["RM"] = "rm -f"
   CONFIG["PKG_CONFIG"] = "pkg-config"
-  CONFIG["PKG_CONFIG_PATH"] = "/opt/local/lib/openssl-1.0/pkgconfig:/opt/local/libexec/openssl10/lib/pkgconfig"
+  CONFIG["PKG_CONFIG_PATH"] = "/opt/local/libexec/openssl10/lib/pkgconfig"
   CONFIG["PYTHON"] = ""
   CONFIG["DOXYGEN"] = ""
   CONFIG["DOT"] = ""
@@ -155,6 +158,7 @@ module RbConfig
   CONFIG["AR"] = "ar"
   CONFIG["RANLIB"] = "ranlib"
   CONFIG["try_header"] = ""
+  CONFIG["CC_VERSION"] = "$(CC) -v"
   CONFIG["COUTFLAG"] = "-o "
   CONFIG["OUTFLAG"] = "-o "
   CONFIG["CPPOUTFILE"] = "-o conftest.i"
@@ -167,8 +171,8 @@ module RbConfig
   CONFIG["CXXFLAGS"] = "-pipe -I/opt/local/libexec/openssl10/include -Os -stdlib=libc++"
   CONFIG["CXX"] = "/usr/bin/clang++"
   CONFIG["OBJEXT"] = "o"
-  CONFIG["CPPFLAGS"] = "-I/opt/local/libexec/openssl10/include -isystem/opt/local/include -D_XOPEN_SOURCE -D_DARWIN_C_SOURCE -D_DARWIN_UNLIMITED_SELECT -D_REENTRANT -I/opt/local/include $(DEFS) $(cppflags)"
-  CONFIG["LDFLAGS"] = "-L. -L/opt/local/libexec/openssl10/lib -L/opt/local/lib -Wl,-headerpad_max_install_names  -arch x86_64 -fstack-protector -L/opt/local/lib "
+  CONFIG["CPPFLAGS"] = "-I/opt/local/libexec/openssl10/include -isystem/opt/local/include -I/opt/local/include -D_XOPEN_SOURCE -D_DARWIN_C_SOURCE -D_DARWIN_UNLIMITED_SELECT -D_REENTRANT $(DEFS) $(cppflags)"
+  CONFIG["LDFLAGS"] = "-L. -L/opt/local/libexec/openssl10/lib -Wl,-headerpad_max_install_names  -arch x86_64 -fstack-protector -L/opt/local/lib -L/opt/local/lib "
   CONFIG["CFLAGS"] = "-pipe -I/opt/local/libexec/openssl10/include -Os -Wno-error=implicit-function-declaration  -arch x86_64 -fno-common"
   CONFIG["CC"] = "/usr/bin/clang"
   CONFIG["NACL_SDK_VARIANT"] = ""
@@ -189,8 +193,8 @@ module RbConfig
   CONFIG["build_vendor"] = "apple"
   CONFIG["build_cpu"] = "x86_64"
   CONFIG["build"] = "x86_64-apple-darwin15"
-  CONFIG["RUBY_RELEASE_DATE"] = "2015-12-16"
-  CONFIG["RUBY_PROGRAM_VERSION"] = "2.0.0"
+  CONFIG["RUBY_RELEASE_DATE"] = "2016-03-30"
+  CONFIG["RUBY_PROGRAM_VERSION"] = "2.1.9"
   CONFIG["target_alias"] = ""
   CONFIG["host_alias"] = ""
   CONFIG["build_alias"] = ""
@@ -218,7 +222,7 @@ module RbConfig
   CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
   CONFIG["sbindir"] = "$(exec_prefix)/sbin"
   CONFIG["bindir"] = "$(exec_prefix)/bin"
-  CONFIG["program_transform_name"] = "s&$$&2.0&;s&^&&"
+  CONFIG["program_transform_name"] = "s&$$&2.1&;s&^&&"
   CONFIG["exec_prefix"] = "$(prefix)"
   CONFIG["PACKAGE_URL"] = ""
   CONFIG["PACKAGE_BUGREPORT"] = ""
